.. _SEO_configuration:

SEO configuration
-----------------

Search engine optimization (SEO) is presented with configuration parameters.

.. tabularcolumns:: |p{3cm}|p{6cm}|p{1.5cm}|p{1.8cm}|p{2cm}|
.. list-table::
   :header-rows: 1

   * - Property
     - Description
     - I18n
     - Required
     - Unique
     
   * - Meta tags
     - Title, description, keywords, photo description
     - yes
     - yes
     - no
     
   * - Slug
     - Part of URL. All spaces and other non alphanumeric characters are changed to hyphen.
     - no
     - yes
     - yes
     
   * - Right Column, Photo
     - Alt property  of <img> tag 
     - yes
     - yes [#f1]_ 
     - no
     
.. rubric:: Footnotes

.. [#f1] If Photo available 

.. seealso::

   `Google recommendation <https://support.google.com/webmasters/answer/35291?hl=en/>`_ for SEO.
